@@ -120,8 +120,6 @@ class Point:
     def _query_params(self) -> dict:
         if self._is_async:
             SyncOnly('Query params only for sync queries.')
-        if not getattr(self, 'list', None):
-            PointError('Query params only for list action.')
         return self.__query_params
 
     @property
